varying lowp vec4 DstColour;
varying highp vec2 TexCoordOut;
uniform sampler2D Texture;
uniform highp float gradientThreshold[20];
uniform lowp vec4 gradientColour[20];
uniform int numElements;

// Example (image used should be grayscale)
// **** DstColour(vert SrcColour) must be set, or you'll probably get black/solid textures;
//
//	f32* gradientThreshold = new f32[5];
//	gradientThreshold[0] = 0;
//	gradientThreshold[1] = 0.15;
//	gradientThreshold[2] = 0.6;
//	gradientThreshold[3] = 0.97;
//	gradientThreshold[4] = 1;
//
//  CVec4* gradientColour = new CVec4[5];
//	gradientColour[0] = 	CVec4(128.0/255.0,	41.0/255.0, 	7.0/255.0,		1);
//	gradientColour[1] = 	CVec4(1, 			110.0/255.0,	2.0/255.0, 		1);
//	gradientColour[2] = 	CVec4(1, 			246.0/255.0, 	0, 				1);
//	gradientColour[3] = 	CVec4(1, 			253.0/255.0, 	192.0/255.0,	1);
//	gradientColour[4] = 	CVec4(1, 			1, 				1, 				1);
//
//	CRenderSystem::SetShaderParameter(COLOURIZE_SHADER_ID, "gradientThreshold[0]", gradientThreshold, sizeof(f32)*5, 0);
//	CRenderSystem::SetShaderParameter(COLOURIZE_SHADER_ID, "gradientColour[0]", gradientColour, sizeof(CVec4)*5, 0);
//	CRenderSystem::SetShaderParameter(COLOURIZE_SHADER_ID, "numElements", new int(5), sizeof(int), 0);

void main(void)
{
    mediump vec4 sampleColour = texture2D(Texture, TexCoordOut) * DstColour;
	mediump float sampleGray = 0.3 * sampleColour.r + 0.59 * sampleColour.g + 0.11 * sampleColour.b;
	
    highp float thresholdLow = gradientThreshold[0];
    lowp vec4 colourLow = gradientColour[0];
    
    // if (sampleGray > gradientThreshold[i]) thresholdLow = gradientThreshold[i];
    // if (sampleGray > gradientThreshold[i]) colourLow = gradientColour[i];
    for (int i = 0; i < numElements; ++i)
    {
        thresholdLow = mix(thresholdLow, gradientThreshold[i], step(gradientThreshold[i], sampleGray));
        colourLow = mix(colourLow, gradientColour[i], step(gradientThreshold[i], sampleGray));
    }
    
    highp float thresholdHigh = gradientThreshold[numElements];
    lowp vec4 colourHigh = gradientColour[numElements];
    
    // if (gradientThreshold[i] > sampleGray) thresholdHigh = gradientThreshold[i];
    // if (gradientThreshold[i] > sampleGray) colourHigh = gradientColour[i];
    for (int i = numElements-1; i >= 0; --i)
    {
        thresholdHigh = mix(thresholdHigh, gradientThreshold[i], step(sampleGray, gradientThreshold[i]));
        colourHigh = mix(colourHigh, gradientColour[i], step(sampleGray, gradientThreshold[i]));
    }
    
    mediump vec4 colourized = mix(colourLow, colourHigh, smoothstep(thresholdLow, thresholdHigh, sampleGray));
    
    gl_FragColor.rgb = colourized.rgb;
    gl_FragColor.a = sampleColour.a * DstColour.a;
}