
// non-shadertoy
//----------
// uniform lowp vec4 Colour;
uniform mediump vec2 iResolution;
uniform mediump vec2 iHighlightPosPx;
uniform lowp float SinRot;
uniform lowp float CosRot;
uniform mediump float iHighlightRadiusPx;
uniform mediump float iHighlightRadiusPxSqrdOvr1;
uniform mediump float iPxToGrid;
uniform lowp vec3 iColor;
uniform lowp vec3 iDotColor;

varying lowp vec2 TexCoordOut;
#define NOT_SHADERTOY
//----------


const lowp float DimpleRadius = 1.0;
const mediump float DimpleRadiusSqrd = DimpleRadius * DimpleRadius;

const lowp float DimpleMinMult = -0.0;

#ifndef NOT_SHADERTOY
const lowp vec3 iColor = vec3(0.7804, 0.8353, 0.8549);
const lowp vec3 iDotColor = vec3(0.5765, 0.7176, 0.7843);

const highp float HighlightRadius = 0.5;
highp float iHighlightRadiusPx = HighlightRadius * sqrt(iResolution.x*iResolution.x + iResolution.y*iResolution.y);

const lowp float Density = 128.0;

#define pi 3.141592653589793238462643383279
const lowp float Rotation = 35.0 * (pi/180.0);
lowp float SinRot = sin(Rotation);
lowp float CosRot = cos(Rotation);
#endif

lowp vec2 RotatePoint( mediump vec2 p )
{
    return vec2( p.x * CosRot - p.y * SinRot,
                 p.x * SinRot + p.y * CosRot );
}

#ifndef NOT_SHADERTOY
void mainImage( out vec4 fragColor, in vec2 fragCoord ) // shadertoy
#else
void main(void)
#endif
{
#ifndef NOT_SHADERTOY
    mediump vec2 FragPos = fragCoord.xy; // shadertoy
#else
    mediump vec2 FragPos = TexCoordOut * iResolution.xy;
#endif
    
#ifndef NOT_SHADERTOY
    mediump vec2 HighlightPositionPx = RotatePoint( iMouse.xy ); // shadertoy
    mediump float iHighlightRadiusPxSqrdOvr1 = iHighlightRadiusPx;
    iHighlightRadiusPxSqrdOvr1 = 1.0 / (iHighlightRadiusPxSqrdOvr1 * iHighlightRadiusPxSqrdOvr1);
#else
    mediump vec2 HighlightPositionPx = iHighlightPosPx;
#endif
    
    lowp vec2 curPosPx = RotatePoint( FragPos.xy );
    
#ifndef NOT_SHADERTOY
    lowp vec2 iDensityXY = vec2( Density, Density * (iResolution.y / iResolution.x) );
    mediump float iPxToGrid = Density / iResolution.x;
#endif
    
    // ( 0, 0 ) -> ( Density, Density )
    highp vec2 c = curPosPx * iPxToGrid;
    
    // ( -0.5, -0.5 ) -> ( 0.5, 0.5 )
    lowp vec2 p = fract(c);
    p -= vec2(0.5);
    
    
    //mediump float CenterDistPx = length(curPosPx - HighlightPositionPx);
    highp vec2 FromCenter = curPosPx - HighlightPositionPx;
    highp float CenterDistPxSqrd = (FromCenter.x * FromCenter.x + FromCenter.y * FromCenter.y);
    
    lowp float RadiusMult = min(1.0, DimpleMinMult + (1.0 - DimpleMinMult) * (CenterDistPxSqrd * iHighlightRadiusPxSqrdOvr1) );
    
    lowp float DimpleCenterDist = sqrt(p.x * p.x + p.y * p.y);
    
    mediump float MixMargin = DimpleRadius * 0.2;
    mediump float DistDif = (DimpleRadius * RadiusMult) - DimpleCenterDist;
    lowp float MixMult = clamp( (DistDif - MixMargin/2.0) / MixMargin, 0.0, 1.0 );
    
#ifndef NOT_SHADERTOY
    fragColor = vec4( mix(iColor, iDotColor, MixMult), 1.0 ); // shadertoy
#else
    gl_FragColor = vec4( mix(iColor, iDotColor, MixMult), 1.0 );
#endif
}