#ifdef GL_OES_standard_derivatives
#	extension GL_OES_standard_derivatives : enable
#endif // GL_OES_standard_derivatives

#define USE_SOFT_EDGES

varying lowp vec4 DstColour;
varying mediump vec2 TexCoordOut;

uniform sampler2D Texture;

uniform lowp vec4 ColourTop;
uniform lowp vec4 ColourBottom;
uniform highp float GradMarginTop;
uniform highp float GradMarginBottom;

void main(void)
{
	const mediump float glyph_edge = 0.5;
	
	mediump float dist = texture2D(Texture, TexCoordOut).a;

	highp float col_r = DstColour.r;
	highp float FractCol = smoothstep( GradMarginBottom, 1.0 - GradMarginTop, col_r );

	lowp vec4 GradientColour = mix( ColourTop, ColourBottom, FractCol );
	lowp vec4 out_colour = GradientColour;
	
#ifdef USE_SOFT_EDGES
	// Perform anisotropic analytic antialiasing
#ifdef GL_OES_standard_derivatives
    mediump float width = fwidth(dist);
    // Catch wire frame artifacts from Tegra graphics processors
    width = mix(width, 0.025, step(0.2, width)); // if (width > 0.2) width = 0.025
#else
    mediump float width = 0.025;
#endif // GL_OES_standard_derivatives
	
	mediump float glyph_edge_0 = glyph_edge - width;
	mediump float glyph_edge_1 = glyph_edge + width;
	
	mediump float alpha = smoothstep(glyph_edge_0, glyph_edge_1, dist);
#else
	mediump float alpha = step(glyph_edge, dist);
#endif // USE_SOFT_EDGES
		
	out_colour.a *= alpha;
	gl_FragColor = out_colour;
}
