#ifdef GL_OES_standard_derivatives
#	extension GL_OES_standard_derivatives : enable
#endif // GL_OES_standard_derivatives

#define USE_SOFT_EDGES
#define USE_OUTLINE

varying lowp vec4 DstColour;
varying mediump vec2 TexCoordOut;

uniform sampler2D Texture;
uniform mediump float OutlineWidth;// = 0.1;
uniform lowp vec4 OutlineColour;// = vec4(0.28235294, 0.28235294, 0.28235294, 1.);

uniform lowp vec4 ColourTop;
uniform lowp vec4 ColourBottom;
uniform highp float GradMarginTop;
uniform highp float GradMarginBottom;

void main(void)
{
	const mediump float glyph_edge = 0.50196;

	mediump float dist = texture2D(Texture, TexCoordOut).a;
	
	highp float col_r = DstColour.r;
	highp float FractCol = smoothstep( GradMarginBottom, 1.0 - GradMarginTop, col_r );

	lowp vec4 GradientColour = mix( ColourTop, ColourBottom, FractCol );
	lowp vec4 out_colour = GradientColour;
	
#ifdef USE_SOFT_EDGES
	// Perform anisotropic analytic antialiasing
#ifdef GL_OES_standard_derivatives
    mediump float width = fwidth(dist);
    // Catch wire frame artifacts from Tegra graphics processors
    width = mix(width, 0.025, step(0.2, width)); // if (width > 0.2) width = 0.025
#else
    mediump float width = 0.025;
#endif // GL_OES_standard_derivatives

	mediump float glyph_edge_0 = glyph_edge - width;
	mediump float glyph_edge_1 = glyph_edge + width;
	
	mediump float alpha = smoothstep(glyph_edge_0, glyph_edge_1, dist);
#else
	mediump float alpha = step(glyph_edge, dist);
#endif // USE_SOFT_EDGES
	
#ifdef USE_OUTLINE
	//outline
	mediump float outline_edge = glyph_edge - OutlineWidth;
	mediump float outline_edge_0 = outline_edge - width;
	mediump float outline_edge_1 = outline_edge + width;
	//only perform outlining step if distance is with outline boundaries
	if (dist >= outline_edge_0 && dist <= glyph_edge_1)
	{
		//AA outline edges
		if (dist <= outline_edge_1)
		{
			alpha = smoothstep(outline_edge_0, outline_edge_1, dist);
			out_colour = OutlineColour;
		}
		//blend with glyph colour for inner edge
		else
		{
			//already computed this gradient inside 'alpha'
			//mediump float mu = smoothstep(glyph_edge_0, glyph_edge_1, dist);
			out_colour = mix(OutlineColour, GradientColour, alpha);  // mu);
			//reset alpha to draw pixel fully
			alpha = 1.;
		}
	}
#endif // USE_OUTLINE
	
	out_colour.a *= alpha;
	gl_FragColor = out_colour;
}
